pub struct RhaiEngineOutput {
pub output: RAVEOutput,
pub rejected_links: Vec<ProcessedLinks>,
pub redacted_links: Vec<ProcessedLinks>,
}Fields
output: RAVEOutputrejected_links: Vec<ProcessedLinks>redacted_links: Vec<ProcessedLinks>Trait Implementations
Sourceimpl Clone for RhaiEngineOutput
impl Clone for RhaiEngineOutput
Sourcefn clone(&self) -> RhaiEngineOutput
fn clone(&self) -> RhaiEngineOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RhaiEngineOutput
impl Debug for RhaiEngineOutput
Sourceimpl<'de> Deserialize<'de> for RhaiEngineOutput
impl<'de> Deserialize<'de> for RhaiEngineOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RhaiEngineOutput
impl PartialEq for RhaiEngineOutput
Sourcefn eq(&self, other: &RhaiEngineOutput) -> bool
fn eq(&self, other: &RhaiEngineOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RhaiEngineOutput
impl Serialize for RhaiEngineOutput
impl StructuralPartialEq for RhaiEngineOutput
Sourceimpl TryFrom<&RhaiEngineOutput> for SerializedBytes
impl TryFrom<&RhaiEngineOutput> for SerializedBytes
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(
t: &RhaiEngineOutput,
) -> Result<SerializedBytes, SerializedBytesError>
fn try_from( t: &RhaiEngineOutput, ) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
Sourceimpl TryFrom<RhaiEngineOutput> for SerializedBytes
impl TryFrom<RhaiEngineOutput> for SerializedBytes
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(
t: RhaiEngineOutput,
) -> Result<SerializedBytes, SerializedBytesError>
fn try_from( t: RhaiEngineOutput, ) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
Sourceimpl TryFrom<SerializedBytes> for RhaiEngineOutput
impl TryFrom<SerializedBytes> for RhaiEngineOutput
Sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
Sourcefn try_from(
sb: SerializedBytes,
) -> Result<RhaiEngineOutput, SerializedBytesError>
fn try_from( sb: SerializedBytes, ) -> Result<RhaiEngineOutput, SerializedBytesError>
Performs the conversion.